# LRU Sequence Mixer

::: linax.sequence_mixers.lru.LRUSequenceMixerConfig
    options:
      members:
        - build

---

::: linax.sequence_mixers.lru.LRUSequenceMixer
    options:
      members:
        - __init__
        - __call__
